Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(759)

Unified Diff: content/browser/download/download_item_impl.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/download/download_item_impl.h
diff --git a/content/browser/download/download_item_impl.h b/content/browser/download/download_item_impl.h
index abf382ed7f4e7c2f42c8e491ecfc553aeee4d8c6..0401370ac4d0fac06487d7cb999a647497d3b92f 100644
--- a/content/browser/download/download_item_impl.h
+++ b/content/browser/download/download_item_impl.h
@@ -50,7 +50,7 @@ class CONTENT_EXPORT DownloadItemImpl
// outlives the DownloadItemImpl.
// Constructing from persistent store:
// |bound_net_log| is constructed externally for our use.
DownloadItemImpl(DownloadItemImplDelegate* delegate,
const std::string& guid,
uint32_t id,
@@ -74,17 +74,17 @@ class CONTENT_EXPORT DownloadItemImpl
DownloadDangerType danger_type,
DownloadInterruptReason interrupt_reason,
bool opened,
- const net::BoundNetLog& bound_net_log);
+ const net::NetLogWithSource& net_log);
// Constructing for a regular download.
// |bound_net_log| is constructed externally for our use.
DownloadItemImpl(DownloadItemImplDelegate* delegate,
uint32_t id,
const DownloadCreateInfo& info,
- const net::BoundNetLog& bound_net_log);
+ const net::NetLogWithSource& net_log);
// Constructing for the "Save Page As..." feature:
// |bound_net_log| is constructed externally for our use.
DownloadItemImpl(
DownloadItemImplDelegate* delegate,
uint32_t id,
@@ -92,7 +92,7 @@ class CONTENT_EXPORT DownloadItemImpl
const GURL& url,
const std::string& mime_type,
std::unique_ptr<DownloadRequestHandleInterface> request_handle,
- const net::BoundNetLog& bound_net_log);
+ const net::NetLogWithSource& net_log);
~DownloadItemImpl() override;
@@ -201,8 +201,8 @@ class CONTENT_EXPORT DownloadItemImpl
virtual base::WeakPtr<DownloadDestinationObserver>
DestinationObserverAsWeakPtr();
- // Get the download's BoundNetLog.
- virtual const net::BoundNetLog& GetBoundNetLog() const;
+ // Get the download's NetLogWithSource.
+ virtual const net::NetLogWithSource& GetNetLogWithSource() const;
// DownloadItemImpl routines only needed by SavePackage ----------------------
@@ -674,7 +674,7 @@ class CONTENT_EXPORT DownloadItemImpl
std::string etag_;
// Net log to use for this download.
- const net::BoundNetLog bound_net_log_;
+ const net::NetLogWithSource net_log_;
base::WeakPtrFactory<DownloadItemImpl> weak_ptr_factory_;

Powered by Google App Engine
@@ -50,7 +50,7 @@ class CONTENT_EXPORT DownloadItemImpl
// outlives the DownloadItemImpl.
// Constructing from persistent store:
- // |bound_net_log| is constructed externally for our use.
+ // |net_log| is constructed externally for our use.
DownloadItemImpl(DownloadItemImplDelegate* delegate,
const std::string& guid,
@@ -74,17 +74,17 @@ class CONTENT_EXPORT DownloadItemImpl
// Constructing for a regular download.
- // |bound_net_log| is constructed externally for our use.
+ // |net_log| is constructed externally for our use.
DownloadItemImpl(DownloadItemImplDelegate* delegate,
uint32_t id,
@@ -74,17 +74,17 @@ class CONTENT_EXPORT DownloadItemImpl
// Constructing for the "Save Page As..." feature:
- // |bound_net_log| is constructed externally for our use.
+ // |net_log| is constructed externally for our use.
DownloadItemImpl(
DownloadItemImplDelegate* delegate,
This is Rietveld 408576698